# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/autos/favourite/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/autos/favourite/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Autos\\Favourite\\": "packages/autos/favourite/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Autos\Favourite\Providers\FavouriteServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Favourite'  => Autos\Favourite\Facades\Favourite::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Autos\\FavouriteTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Autos\Favourite\Providers\FavouriteServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Autos\Favourite\Providers\FavouriteServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Autos\Favourite\Providers\FavouriteServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/favourite/{modulename}

**User**

    http://path-to-route-folder/user/favourite/{modulename}

**Public**

    http://path-to-route-folder/favourites


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/favourite/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/favourite/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/favourite/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/favourite/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/favourite/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/favourite/{modulename}/{slug}
    METHOD: GET