<?php

namespace Autos\Favourite\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Autos\Favourite\Interfaces\FavouriteRepositoryInterface;

class FavouritePublicController extends BaseController
{
    // use FavouriteWorkflow;

    /**
     * Constructor.
     *
     * @param type \Autos\Favourite\Interfaces\FavouriteRepositoryInterface $favourite
     *
     * @return type
     */
    public function __construct(FavouriteRepositoryInterface $favourite)
    {
        $this->repository = $favourite;
        parent::__construct();
    }

    /**
     * Show favourite's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $favourites = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->setMetaTitle(trans('favourite::favourite.names'))
            ->view('favourite::public.favourite.index')
            ->data(compact('favourites'))
            ->output();
    }


    /**
     * Show favourite.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $favourite = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->setMetaTitle($favourite->name . trans('favourite::favourite.name'))
            ->view('favourite::public.favourite.show')
            ->data(compact('favourite'))
            ->output();
    }

}
