<?php

namespace Autos\Favourite\Policies;

use Litepie\User\Contracts\UserPolicy;
use Autos\Favourite\Models\Favourite;

class FavouritePolicy
{

    /**
     * Determine if the given user can view the favourite.
     *
     * @param UserPolicy $user
     * @param Favourite $favourite
     *
     * @return bool
     */
    public function view(UserPolicy $user, Favourite $favourite)
    {
        if ($user->canDo('favourite.favourite.view') && $user->isAdmin()) {
            return true;
        }

        return $favourite->user_id == user_id() && $favourite->user_type == user_type();
    }

    /**
     * Determine if the given user can create a favourite.
     *
     * @param UserPolicy $user
     * @param Favourite $favourite
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('favourite.favourite.create');
    }

    /**
     * Determine if the given user can update the given favourite.
     *
     * @param UserPolicy $user
     * @param Favourite $favourite
     *
     * @return bool
     */
    public function update(UserPolicy $user, Favourite $favourite)
    {
        if ($user->canDo('favourite.favourite.edit') && $user->isAdmin()) {
            return true;
        }

        return $favourite->user_id == user_id() && $favourite->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given favourite.
     *
     * @param UserPolicy $user
     * @param Favourite $favourite
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Favourite $favourite)
    {
        return $favourite->user_id == user_id() && $favourite->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given favourite.
     *
     * @param UserPolicy $user
     * @param Favourite $favourite
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Favourite $favourite)
    {
        if ($user->canDo('favourite.favourite.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given favourite.
     *
     * @param UserPolicy $user
     * @param Favourite $favourite
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Favourite $favourite)
    {
        if ($user->canDo('favourite.favourite.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
